# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from . import miscellaneous_pb2 as miscellaneous__pb2
from . import stickers_pb2 as stickers__pb2


class StickersStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.LoadOwnStickers = channel.unary_unary(
                '/dialog.Stickers/LoadOwnStickers',
                request_serializer=stickers__pb2.RequestLoadOwnStickers.SerializeToString,
                response_deserializer=stickers__pb2.ResponseLoadOwnStickers.FromString,
                )
        self.LoadAcesssibleStickers = channel.unary_unary(
                '/dialog.Stickers/LoadAcesssibleStickers',
                request_serializer=stickers__pb2.RequestLoadAcesssibleStickers.SerializeToString,
                response_deserializer=stickers__pb2.ResponseLoadAcesssibleStickers.FromString,
                )
        self.AddStickerPackReference = channel.unary_unary(
                '/dialog.Stickers/AddStickerPackReference',
                request_serializer=stickers__pb2.RequestAddStickerPackReference.SerializeToString,
                response_deserializer=miscellaneous__pb2.ResponseSeq.FromString,
                )
        self.RemoveStickerPackReference = channel.unary_unary(
                '/dialog.Stickers/RemoveStickerPackReference',
                request_serializer=stickers__pb2.RequestRemoveStickerPackReference.SerializeToString,
                response_deserializer=miscellaneous__pb2.ResponseSeq.FromString,
                )
        self.AddStickerCollection = channel.unary_unary(
                '/dialog.Stickers/AddStickerCollection',
                request_serializer=stickers__pb2.RequestAddStickerCollection.SerializeToString,
                response_deserializer=miscellaneous__pb2.ResponseSeq.FromString,
                )
        self.RemoveStickerCollection = channel.unary_unary(
                '/dialog.Stickers/RemoveStickerCollection',
                request_serializer=stickers__pb2.RequestRemoveStickerCollection.SerializeToString,
                response_deserializer=miscellaneous__pb2.ResponseSeq.FromString,
                )
        self.LoadStickerCollection = channel.unary_unary(
                '/dialog.Stickers/LoadStickerCollection',
                request_serializer=stickers__pb2.RequestLoadStickerCollection.SerializeToString,
                response_deserializer=stickers__pb2.ResponseLoadStickerCollection.FromString,
                )


class StickersServicer(object):
    """Missing associated documentation comment in .proto file."""

    def LoadOwnStickers(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def LoadAcesssibleStickers(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AddStickerPackReference(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RemoveStickerPackReference(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AddStickerCollection(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RemoveStickerCollection(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def LoadStickerCollection(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_StickersServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'LoadOwnStickers': grpc.unary_unary_rpc_method_handler(
                    servicer.LoadOwnStickers,
                    request_deserializer=stickers__pb2.RequestLoadOwnStickers.FromString,
                    response_serializer=stickers__pb2.ResponseLoadOwnStickers.SerializeToString,
            ),
            'LoadAcesssibleStickers': grpc.unary_unary_rpc_method_handler(
                    servicer.LoadAcesssibleStickers,
                    request_deserializer=stickers__pb2.RequestLoadAcesssibleStickers.FromString,
                    response_serializer=stickers__pb2.ResponseLoadAcesssibleStickers.SerializeToString,
            ),
            'AddStickerPackReference': grpc.unary_unary_rpc_method_handler(
                    servicer.AddStickerPackReference,
                    request_deserializer=stickers__pb2.RequestAddStickerPackReference.FromString,
                    response_serializer=miscellaneous__pb2.ResponseSeq.SerializeToString,
            ),
            'RemoveStickerPackReference': grpc.unary_unary_rpc_method_handler(
                    servicer.RemoveStickerPackReference,
                    request_deserializer=stickers__pb2.RequestRemoveStickerPackReference.FromString,
                    response_serializer=miscellaneous__pb2.ResponseSeq.SerializeToString,
            ),
            'AddStickerCollection': grpc.unary_unary_rpc_method_handler(
                    servicer.AddStickerCollection,
                    request_deserializer=stickers__pb2.RequestAddStickerCollection.FromString,
                    response_serializer=miscellaneous__pb2.ResponseSeq.SerializeToString,
            ),
            'RemoveStickerCollection': grpc.unary_unary_rpc_method_handler(
                    servicer.RemoveStickerCollection,
                    request_deserializer=stickers__pb2.RequestRemoveStickerCollection.FromString,
                    response_serializer=miscellaneous__pb2.ResponseSeq.SerializeToString,
            ),
            'LoadStickerCollection': grpc.unary_unary_rpc_method_handler(
                    servicer.LoadStickerCollection,
                    request_deserializer=stickers__pb2.RequestLoadStickerCollection.FromString,
                    response_serializer=stickers__pb2.ResponseLoadStickerCollection.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'dialog.Stickers', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Stickers(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def LoadOwnStickers(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dialog.Stickers/LoadOwnStickers',
            stickers__pb2.RequestLoadOwnStickers.SerializeToString,
            stickers__pb2.ResponseLoadOwnStickers.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def LoadAcesssibleStickers(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dialog.Stickers/LoadAcesssibleStickers',
            stickers__pb2.RequestLoadAcesssibleStickers.SerializeToString,
            stickers__pb2.ResponseLoadAcesssibleStickers.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def AddStickerPackReference(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dialog.Stickers/AddStickerPackReference',
            stickers__pb2.RequestAddStickerPackReference.SerializeToString,
            miscellaneous__pb2.ResponseSeq.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RemoveStickerPackReference(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dialog.Stickers/RemoveStickerPackReference',
            stickers__pb2.RequestRemoveStickerPackReference.SerializeToString,
            miscellaneous__pb2.ResponseSeq.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def AddStickerCollection(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dialog.Stickers/AddStickerCollection',
            stickers__pb2.RequestAddStickerCollection.SerializeToString,
            miscellaneous__pb2.ResponseSeq.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RemoveStickerCollection(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dialog.Stickers/RemoveStickerCollection',
            stickers__pb2.RequestRemoveStickerCollection.SerializeToString,
            miscellaneous__pb2.ResponseSeq.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def LoadStickerCollection(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dialog.Stickers/LoadStickerCollection',
            stickers__pb2.RequestLoadStickerCollection.SerializeToString,
            stickers__pb2.ResponseLoadStickerCollection.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from . import miscellaneous_pb2 as miscellaneous__pb2
from . import users_pb2 as users__pb2


class UsersStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.EditUserLocalName = channel.unary_unary(
                '/dialog.Users/EditUserLocalName',
                request_serializer=users__pb2.RequestEditUserLocalName.SerializeToString,
                response_deserializer=miscellaneous__pb2.ResponseSeq.FromString,
                )
        self.LoadFullUsers = channel.unary_unary(
                '/dialog.Users/LoadFullUsers',
                request_serializer=users__pb2.RequestLoadFullUsers.SerializeToString,
                response_deserializer=users__pb2.ResponseLoadFullUsers.FromString,
                )
        self.LoadUserData = channel.unary_unary(
                '/dialog.Users/LoadUserData',
                request_serializer=users__pb2.RequestLoadUserData.SerializeToString,
                response_deserializer=users__pb2.ResponseLoadUserData.FromString,
                )


class UsersServicer(object):
    """Missing associated documentation comment in .proto file."""

    def EditUserLocalName(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def LoadFullUsers(self, request, context):
        """/ Deprecated
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def LoadUserData(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_UsersServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'EditUserLocalName': grpc.unary_unary_rpc_method_handler(
                    servicer.EditUserLocalName,
                    request_deserializer=users__pb2.RequestEditUserLocalName.FromString,
                    response_serializer=miscellaneous__pb2.ResponseSeq.SerializeToString,
            ),
            'LoadFullUsers': grpc.unary_unary_rpc_method_handler(
                    servicer.LoadFullUsers,
                    request_deserializer=users__pb2.RequestLoadFullUsers.FromString,
                    response_serializer=users__pb2.ResponseLoadFullUsers.SerializeToString,
            ),
            'LoadUserData': grpc.unary_unary_rpc_method_handler(
                    servicer.LoadUserData,
                    request_deserializer=users__pb2.RequestLoadUserData.FromString,
                    response_serializer=users__pb2.ResponseLoadUserData.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'dialog.Users', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Users(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def EditUserLocalName(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dialog.Users/EditUserLocalName',
            users__pb2.RequestEditUserLocalName.SerializeToString,
            miscellaneous__pb2.ResponseSeq.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def LoadFullUsers(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dialog.Users/LoadFullUsers',
            users__pb2.RequestLoadFullUsers.SerializeToString,
            users__pb2.ResponseLoadFullUsers.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def LoadUserData(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dialog.Users/LoadUserData',
            users__pb2.RequestLoadUserData.SerializeToString,
            users__pb2.ResponseLoadUserData.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: push_content.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import definitions_pb2 as definitions__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='push_content.proto',
  package='dialog',
  syntax='proto3',
  serialized_options=b'Z\006dialog',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x12push_content.proto\x12\x06\x64ialog\x1a\x11\x64\x65\x66initions.proto\"6\n\x11LocalizableString\x12\x0f\n\x07loc_key\x18\x01 \x01(\t\x12\x10\n\x08loc_args\x18\x02 \x03(\t\"J\n\x08PushPeer\x12\"\n\x04type\x18\x01 \x01(\x0e\x32\x14.dialog.PushPeerType\x12\n\n\x02id\x18\x02 \x01(\x05\x12\x0e\n\x06str_id\x18\x03 \x01(\t\"\xd2\x03\n\x14\x45ncryptedPushContent\x12\x33\n\x0eloc_alert_body\x18\x01 \x01(\x0b\x32\x19.dialog.LocalizableStringH\x00\x12\x1b\n\x11simple_alert_body\x18\x02 \x01(\tH\x00\x12\x34\n\x0floc_alert_title\x18\x03 \x01(\x0b\x32\x19.dialog.LocalizableStringH\x01\x12\x1c\n\x12simple_alert_title\x18\x04 \x01(\tH\x01\x12\r\n\x05sound\x18\x05 \x01(\t\x12\x1e\n\x16unread_message_counter\x18\x06 \x01(\x05\x12\x1e\n\x04peer\x18\x07 \x01(\x0b\x32\x10.dialog.PushPeer\x12\x34\n\nmessage_id\x18\n \x01(\x0b\x32\x11.dialog.UUIDValueB\r\x8a\xea\x30\t\n\x07visible\x12\x15\n\risRespondable\x18\x0b \x01(\x08\x12\x16\n\x0esender_user_id\x18\x0c \x01(\x05\x12\x0c\n\x04\x64\x61te\x18\r \x01(\x03\x12)\n\nevent_type\x18\x0e \x01(\x0e\x32\x15.dialog.PushEventTypeB\x0c\n\nalert_bodyB\r\n\x0b\x61lert_titleJ\x04\x08\x08\x10\tJ\x04\x08\t\x10\n*\\\n\x0cPushPeerType\x12\x1a\n\x16PUSH_PEER_TYPE_PRIVATE\x10\x00\x12\x18\n\x14PUSH_PEER_TYPE_GROUP\x10\x01\x12\x16\n\x12PUSH_PEER_TYPE_SIP\x10\x02*3\n\rPushEventType\x12\n\n\x06\x43REATE\x10\x00\x12\n\n\x06UPDATE\x10\x01\x12\n\n\x06\x44\x45LETE\x10\x02\x42\x08Z\x06\x64ialogb\x06proto3'
  ,
  dependencies=[definitions__pb2.DESCRIPTOR,])

_PUSHPEERTYPE = _descriptor.EnumDescriptor(
  name='PushPeerType',
  full_name='dialog.PushPeerType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='PUSH_PEER_TYPE_PRIVATE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PUSH_PEER_TYPE_GROUP', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PUSH_PEER_TYPE_SIP', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=650,
  serialized_end=742,
)
_sym_db.RegisterEnumDescriptor(_PUSHPEERTYPE)

PushPeerType = enum_type_wrapper.EnumTypeWrapper(_PUSHPEERTYPE)
_PUSHEVENTTYPE = _descriptor.EnumDescriptor(
  name='PushEventType',
  full_name='dialog.PushEventType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CREATE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UPDATE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DELETE', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=744,
  serialized_end=795,
)
_sym_db.RegisterEnumDescriptor(_PUSHEVENTTYPE)

PushEventType = enum_type_wrapper.EnumTypeWrapper(_PUSHEVENTTYPE)
PUSH_PEER_TYPE_PRIVATE = 0
PUSH_PEER_TYPE_GROUP = 1
PUSH_PEER_TYPE_SIP = 2
CREATE = 0
UPDATE = 1
DELETE = 2



_LOCALIZABLESTRING = _descriptor.Descriptor(
  name='LocalizableString',
  full_name='dialog.LocalizableString',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='loc_key', full_name='dialog.LocalizableString.loc_key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='loc_args', full_name='dialog.LocalizableString.loc_args', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=49,
  serialized_end=103,
)


_PUSHPEER = _descriptor.Descriptor(
  name='PushPeer',
  full_name='dialog.PushPeer',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='dialog.PushPeer.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='id', full_name='dialog.PushPeer.id', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='str_id', full_name='dialog.PushPeer.str_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=105,
  serialized_end=179,
)


_ENCRYPTEDPUSHCONTENT = _descriptor.Descriptor(
  name='EncryptedPushContent',
  full_name='dialog.EncryptedPushContent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='loc_alert_body', full_name='dialog.EncryptedPushContent.loc_alert_body', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='simple_alert_body', full_name='dialog.EncryptedPushContent.simple_alert_body', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='loc_alert_title', full_name='dialog.EncryptedPushContent.loc_alert_title', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='simple_alert_title', full_name='dialog.EncryptedPushContent.simple_alert_title', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sound', full_name='dialog.EncryptedPushContent.sound', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='unread_message_counter', full_name='dialog.EncryptedPushContent.unread_message_counter', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='peer', full_name='dialog.EncryptedPushContent.peer', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='message_id', full_name='dialog.EncryptedPushContent.message_id', index=7,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='isRespondable', full_name='dialog.EncryptedPushContent.isRespondable', index=8,
      number=11, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sender_user_id', full_name='dialog.EncryptedPushContent.sender_user_id', index=9,
      number=12, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='date', full_name='dialog.EncryptedPushContent.date', index=10,
      number=13, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='event_type', full_name='dialog.EncryptedPushContent.event_type', index=11,
      number=14, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='alert_body', full_name='dialog.EncryptedPushContent.alert_body',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='alert_title', full_name='dialog.EncryptedPushContent.alert_title',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=182,
  serialized_end=648,
)

_PUSHPEER.fields_by_name['type'].enum_type = _PUSHPEERTYPE
_ENCRYPTEDPUSHCONTENT.fields_by_name['loc_alert_body'].message_type = _LOCALIZABLESTRING
_ENCRYPTEDPUSHCONTENT.fields_by_name['loc_alert_title'].message_type = _LOCALIZABLESTRING
_ENCRYPTEDPUSHCONTENT.fields_by_name['peer'].message_type = _PUSHPEER
_ENCRYPTEDPUSHCONTENT.fields_by_name['message_id'].message_type = definitions__pb2._UUIDVALUE
_ENCRYPTEDPUSHCONTENT.fields_by_name['event_type'].enum_type = _PUSHEVENTTYPE
_ENCRYPTEDPUSHCONTENT.oneofs_by_name['alert_body'].fields.append(
  _ENCRYPTEDPUSHCONTENT.fields_by_name['loc_alert_body'])
_ENCRYPTEDPUSHCONTENT.fields_by_name['loc_alert_body'].containing_oneof = _ENCRYPTEDPUSHCONTENT.oneofs_by_name['alert_body']
_ENCRYPTEDPUSHCONTENT.oneofs_by_name['alert_body'].fields.append(
  _ENCRYPTEDPUSHCONTENT.fields_by_name['simple_alert_body'])
_ENCRYPTEDPUSHCONTENT.fields_by_name['simple_alert_body'].containing_oneof = _ENCRYPTEDPUSHCONTENT.oneofs_by_name['alert_body']
_ENCRYPTEDPUSHCONTENT.oneofs_by_name['alert_title'].fields.append(
  _ENCRYPTEDPUSHCONTENT.fields_by_name['loc_alert_title'])
_ENCRYPTEDPUSHCONTENT.fields_by_name['loc_alert_title'].containing_oneof = _ENCRYPTEDPUSHCONTENT.oneofs_by_name['alert_title']
_ENCRYPTEDPUSHCONTENT.oneofs_by_name['alert_title'].fields.append(
  _ENCRYPTEDPUSHCONTENT.fields_by_name['simple_alert_title'])
_ENCRYPTEDPUSHCONTENT.fields_by_name['simple_alert_title'].containing_oneof = _ENCRYPTEDPUSHCONTENT.oneofs_by_name['alert_title']
DESCRIPTOR.message_types_by_name['LocalizableString'] = _LOCALIZABLESTRING
DESCRIPTOR.message_types_by_name['PushPeer'] = _PUSHPEER
DESCRIPTOR.message_types_by_name['EncryptedPushContent'] = _ENCRYPTEDPUSHCONTENT
DESCRIPTOR.enum_types_by_name['PushPeerType'] = _PUSHPEERTYPE
DESCRIPTOR.enum_types_by_name['PushEventType'] = _PUSHEVENTTYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

LocalizableString = _reflection.GeneratedProtocolMessageType('LocalizableString', (_message.Message,), {
  'DESCRIPTOR' : _LOCALIZABLESTRING,
  '__module__' : 'push_content_pb2'
  # @@protoc_insertion_point(class_scope:dialog.LocalizableString)
  })
_sym_db.RegisterMessage(LocalizableString)

PushPeer = _reflection.GeneratedProtocolMessageType('PushPeer', (_message.Message,), {
  'DESCRIPTOR' : _PUSHPEER,
  '__module__' : 'push_content_pb2'
  # @@protoc_insertion_point(class_scope:dialog.PushPeer)
  })
_sym_db.RegisterMessage(PushPeer)

EncryptedPushContent = _reflection.GeneratedProtocolMessageType('EncryptedPushContent', (_message.Message,), {
  'DESCRIPTOR' : _ENCRYPTEDPUSHCONTENT,
  '__module__' : 'push_content_pb2'
  # @@protoc_insertion_point(class_scope:dialog.EncryptedPushContent)
  })
_sym_db.RegisterMessage(EncryptedPushContent)


DESCRIPTOR._options = None
_ENCRYPTEDPUSHCONTENT.fields_by_name['message_id']._options = None
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from . import messaging_pb2 as messaging__pb2
from . import miscellaneous_pb2 as miscellaneous__pb2


class MessagingStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.DoInteractiveMediaAction = channel.unary_unary(
                '/dialog.Messaging/DoInteractiveMediaAction',
                request_serializer=messaging__pb2.RequestDoInteractiveMediaAction.SerializeToString,
                response_deserializer=miscellaneous__pb2.ResponseVoid.FromString,
                )
        self.SendMessage = channel.unary_unary(
                '/dialog.Messaging/SendMessage',
                request_serializer=messaging__pb2.RequestSendMessage.SerializeToString,
                response_deserializer=messaging__pb2.ResponseSendMessage.FromString,
                )
        self.UpdateMessage = channel.unary_unary(
                '/dialog.Messaging/UpdateMessage',
                request_serializer=messaging__pb2.RequestUpdateMessage.SerializeToString,
                response_deserializer=miscellaneous__pb2.ResponseSeqDate.FromString,
                )
        self.MessageReceived = channel.unary_unary(
                '/dialog.Messaging/MessageReceived',
                request_serializer=messaging__pb2.RequestMessageReceived.SerializeToString,
                response_deserializer=miscellaneous__pb2.ResponseVoid.FromString,
                )
        self.MessageRead = channel.unary_unary(
                '/dialog.Messaging/MessageRead',
                request_serializer=messaging__pb2.RequestMessageRead.SerializeToString,
                response_deserializer=miscellaneous__pb2.ResponseVoid.FromString,
                )
        self.DeleteMessageObsolete = channel.unary_unary(
                '/dialog.Messaging/DeleteMessageObsolete',
                request_serializer=messaging__pb2.RequestDeleteMessageObsolete.SerializeToString,
                response_deserializer=miscellaneous__pb2.ResponseSeq.FromString,
                )
        self.DeleteMessage = channel.unary_unary(
                '/dialog.Messaging/DeleteMessage',
                request_serializer=messaging__pb2.RequestDeleteMessage.SerializeToString,
                response_deserializer=miscellaneous__pb2.ResponseVoid.FromString,
                )
        self.ClearChat = channel.unary_unary(
                '/dialog.Messaging/ClearChat',
                request_serializer=messaging__pb2.RequestClearChat.SerializeToString,
                response_deserializer=miscellaneous__pb2.ResponseSeq.FromString,
                )
        self.DeleteChat = channel.unary_unary(
                '/dialog.Messaging/DeleteChat',
                request_serializer=messaging__pb2.RequestDeleteChat.SerializeToString,
                response_deserializer=miscellaneous__pb2.ResponseSeq.FromString,
                )
        self.ArchiveChat = channel.unary_unary(
                '/dialog.Messaging/ArchiveChat',
                request_serializer=messaging__pb2.RequestArchiveChat.SerializeToString,
                response_deserializer=miscellaneous__pb2.ResponseSeq.FromString,
                )
        self.MessageSetReaction = channel.unary_unary(
                '/dialog.Messaging/MessageSetReaction',
                request_serializer=messaging__pb2.RequestMessageSetReaction.SerializeToString,
                response_deserializer=messaging__pb2.ResponseReactionsResponse.FromString,
                )
        self.MessageRemoveReaction = channel.unary_unary(
                '/dialog.Messaging/MessageRemoveReaction',
                request_serializer=messaging__pb2.RequestMessageRemoveReaction.SerializeToString,
                response_deserializer=messaging__pb2.ResponseReactionsResponse.FromString,
                )
        self.LoadHistory = channel.unary_unary(
                '/dialog.Messaging/LoadHistory',
                request_serializer=messaging__pb2.RequestLoadHistory.SerializeToString,
                response_deserializer=messaging__pb2.ResponseLoadHistory.FromString,
                )
        self.HistoryDifference = channel.unary_unary(
                '/dialog.Messaging/HistoryDifference',
                request_serializer=messaging__pb2.RequestHistoryDifference.SerializeToString,
                response_deserializer=messaging__pb2.ResponseHistoryDifference.FromString,
                )
        self.LoadDialogs = channel.unary_unary(
                '/dialog.Messaging/LoadDialogs',
                request_serializer=messaging__pb2.RequestLoadDialogs.SerializeToString,
                response_deserializer=messaging__pb2.ResponseLoadDialogs.FromString,
                )
        self.FetchDialogIndex = channel.unary_unary(
                '/dialog.Messaging/FetchDialogIndex',
                request_serializer=messaging__pb2.RequestFetchDialogIndex.SerializeToString,
                response_deserializer=messaging__pb2.ResponseFetchDialogIndex.FromString,
                )
        self.DialogListDifference = channel.unary_unary(
                '/dialog.Messaging/DialogListDifference',
                request_serializer=messaging__pb2.RequestDialogListDifference.SerializeToString,
                response_deserializer=messaging__pb2.ResponseDialogListDifference.FromString,
                )
        self.GetLastConversationMessages = channel.unary_unary(
                '/dialog.Messaging/GetLastConversationMessages',
                request_serializer=messaging__pb2.RequestGetLastConversationMessages.SerializeToString,
                response_deserializer=messaging__pb2.ResponseGetLastConversationMessages.FromString,
                )
        self.LoadArchived = channel.unary_unary(
                '/dialog.Messaging/LoadArchived',
                request_serializer=messaging__pb2.RequestLoadArchived.SerializeToString,
                response_deserializer=messaging__pb2.ResponseLoadArchived.FromString,
                )
        self.LoadGroupedDialogs = channel.unary_unary(
                '/dialog.Messaging/LoadGroupedDialogs',
                request_serializer=messaging__pb2.RequestLoadGroupedDialogs.SerializeToString,
                response_deserializer=messaging__pb2.ResponseLoadGroupedDialogs.FromString,
                )
        self.HideDialog = channel.unary_unary(
                '/dialog.Messaging/HideDialog',
                request_serializer=messaging__pb2.RequestHideDialog.SerializeToString,
                response_deserializer=messaging__pb2.ResponseDialogsOrder.FromString,
                )
        self.ShowDialog = channel.unary_unary(
                '/dialog.Messaging/ShowDialog',
                request_serializer=messaging__pb2.RequestShowDialog.SerializeToString,
                response_deserializer=messaging__pb2.ResponseDialogsOrder.FromString,
                )
        self.FavouriteDialog = channel.unary_unary(
                '/dialog.Messaging/FavouriteDialog',
                request_serializer=messaging__pb2.RequestFavouriteDialog.SerializeToString,
                response_deserializer=messaging__pb2.ResponseDialogsOrder.FromString,
                )
        self.UnfavouriteDialog = channel.unary_unary(
                '/dialog.Messaging/UnfavouriteDialog',
                request_serializer=messaging__pb2.RequestUnfavouriteDialog.SerializeToString,
                response_deserializer=messaging__pb2.ResponseDialogsOrder.FromString,
                )
        self.NotifyDialogOpened = channel.unary_unary(
                '/dialog.Messaging/NotifyDialogOpened',
                request_serializer=messaging__pb2.RequestNotifyDialogOpened.SerializeToString,
                response_deserializer=miscellaneous__pb2.ResponseVoid.FromString,
                )
        self.PinMessage = channel.unary_unary(
                '/dialog.Messaging/PinMessage',
                request_serializer=messaging__pb2.RequestPinMessage.SerializeToString,
                response_deserializer=miscellaneous__pb2.ResponseSeqDate.FromString,
                )
        self.UnpinMessage = channel.unary_unary(
                '/dialog.Messaging/UnpinMessage',
                request_serializer=messaging__pb2.RequestUnpinMessage.SerializeToString,
                response_deserializer=miscellaneous__pb2.ResponseSeqDate.FromString,
                )
        self.GetUpdatedMessages = channel.unary_unary(
                '/dialog.Messaging/GetUpdatedMessages',
                request_serializer=messaging__pb2.RequestGetUpdatedMessages.SerializeToString,
                response_deserializer=messaging__pb2.ResponseGetUpdatedMessages.FromString,
                )
        self.GetMessageReads = channel.unary_unary(
                '/dialog.Messaging/GetMessageReads',
                request_serializer=messaging__pb2.RequestMessageReads.SerializeToString,
                response_deserializer=messaging__pb2.ResponseMessageReads.FromString,
                )
        self.GetMessageReceives = channel.unary_unary(
                '/dialog.Messaging/GetMessageReceives',
                request_serializer=messaging__pb2.RequestMessageReceives.SerializeToString,
                response_deserializer=messaging__pb2.ResponseMessageReceives.FromString,
                )
        self.ReadDialogLater = channel.unary_unary(
                '/dialog.Messaging/ReadDialogLater',
                request_serializer=messaging__pb2.RequestReadDialogLater.SerializeToString,
                response_deserializer=miscellaneous__pb2.ResponseVoid.FromString,
                )


class MessagingServicer(object):
    """Missing associated documentation comment in .proto file."""

    def DoInteractiveMediaAction(self, request, context):
        """/ Interact with a message media (click on button for example)
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SendMessage(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateMessage(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def MessageReceived(self, request, context):
        """/ Mark message as received by self
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def MessageRead(self, request, context):
        """/ Mark message as read by self
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteMessageObsolete(self, request, context):
        """/ deprecated
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteMessage(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ClearChat(self, request, context):
        """/ Clear chat history
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteChat(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ArchiveChat(self, request, context):
        """/ deprecated
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def MessageSetReaction(self, request, context):
        """/ Add reaction on message (emoji)
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def MessageRemoveReaction(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def LoadHistory(self, request, context):
        """/ Load conversation history
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def HistoryDifference(self, request, context):
        """/ Load total history difference for all user's conversations
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def LoadDialogs(self, request, context):
        """/ Load user's dialogs
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def FetchDialogIndex(self, request, context):
        """/ Load short info about all user's dialogs
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DialogListDifference(self, request, context):
        """/ Load dialogs by peers
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetLastConversationMessages(self, request, context):
        """/ Load last messages of the given conversations
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def LoadArchived(self, request, context):
        """/ deprecated
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def LoadGroupedDialogs(self, request, context):
        """/ deprecated
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def HideDialog(self, request, context):
        """/ deprecated
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ShowDialog(self, request, context):
        """/ deprecated
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def FavouriteDialog(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UnfavouriteDialog(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def NotifyDialogOpened(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def PinMessage(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UnpinMessage(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetUpdatedMessages(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetMessageReads(self, request, context):
        """Returns read status of the message per user
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetMessageReceives(self, request, context):
        """Returns receive status of the message per user
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ReadDialogLater(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_MessagingServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'DoInteractiveMediaAction': grpc.unary_unary_rpc_method_handler(
                    servicer.DoInteractiveMediaAction,
                    request_deserializer=messaging__pb2.RequestDoInteractiveMediaAction.FromString,
                    response_serializer=miscellaneous__pb2.ResponseVoid.SerializeToString,
            ),
            'SendMessage': grpc.unary_unary_rpc_method_handler(
                    servicer.SendMessage,
                    request_deserializer=messaging__pb2.RequestSendMessage.FromString,
                    response_serializer=messaging__pb2.ResponseSendMessage.SerializeToString,
            ),
            'UpdateMessage': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateMessage,
                    request_deserializer=messaging__pb2.RequestUpdateMessage.FromString,
                    response_serializer=miscellaneous__pb2.ResponseSeqDate.SerializeToString,
            ),
            'MessageReceived': grpc.unary_unary_rpc_method_handler(
                    servicer.MessageReceived,
                    request_deserializer=messaging__pb2.RequestMessageReceived.FromString,
                    response_serializer=miscellaneous__pb2.ResponseVoid.SerializeToString,
            ),
            'MessageRead': grpc.unary_unary_rpc_method_handler(
                    servicer.MessageRead,
                    request_deserializer=messaging__pb2.RequestMessageRead.FromString,
                    response_serializer=miscellaneous__pb2.ResponseVoid.SerializeToString,
            ),
            'DeleteMessageObsolete': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteMessageObsolete,
                    request_deserializer=messaging__pb2.RequestDeleteMessageObsolete.FromString,
                    response_serializer=miscellaneous__pb2.ResponseSeq.SerializeToString,
            ),
            'DeleteMessage': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteMessage,
                    request_deserializer=messaging__pb2.RequestDeleteMessage.FromString,
                    response_serializer=miscellaneous__pb2.ResponseVoid.SerializeToString,
            ),
            'ClearChat': grpc.unary_unary_rpc_method_handler(
                    servicer.ClearChat,
                    request_deserializer=messaging__pb2.RequestClearChat.FromString,
                    response_serializer=miscellaneous__pb2.ResponseSeq.SerializeToString,
            ),
            'DeleteChat': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteChat,
                    request_deserializer=messaging__pb2.RequestDeleteChat.FromString,
                    response_serializer=miscellaneous__pb2.ResponseSeq.SerializeToString,
            ),
            'ArchiveChat': grpc.unary_unary_rpc_method_handler(
                    servicer.ArchiveChat,
                    request_deserializer=messaging__pb2.RequestArchiveChat.FromString,
                    response_serializer=miscellaneous__pb2.ResponseSeq.SerializeToString,
            ),
            'MessageSetReaction': grpc.unary_unary_rpc_method_handler(
                    servicer.MessageSetReaction,
                    request_deserializer=messaging__pb2.RequestMessageSetReaction.FromString,
                    response_serializer=messaging__pb2.ResponseReactionsResponse.SerializeToString,
            ),
            'MessageRemoveReaction': grpc.unary_unary_rpc_method_handler(
                    servicer.MessageRemoveReaction,
                    request_deserializer=messaging__pb2.RequestMessageRemoveReaction.FromString,
                    response_serializer=messaging__pb2.ResponseReactionsResponse.SerializeToString,
            ),
            'LoadHistory': grpc.unary_unary_rpc_method_handler(
                    servicer.LoadHistory,
                    request_deserializer=messaging__pb2.RequestLoadHistory.FromString,
                    response_serializer=messaging__pb2.ResponseLoadHistory.SerializeToString,
            ),
            'HistoryDifference': grpc.unary_unary_rpc_method_handler(
                    servicer.HistoryDifference,
                    request_deserializer=messaging__pb2.RequestHistoryDifference.FromString,
                    response_serializer=messaging__pb2.ResponseHistoryDifference.SerializeToString,
            ),
            'LoadDialogs': grpc.unary_unary_rpc_method_handler(
                    servicer.LoadDialogs,
                    request_deserializer=messaging__pb2.RequestLoadDialogs.FromString,
                    response_serializer=messaging__pb2.ResponseLoadDialogs.SerializeToString,
            ),
            'FetchDialogIndex': grpc.unary_unary_rpc_method_handler(
                    servicer.FetchDialogIndex,
                    request_deserializer=messaging__pb2.RequestFetchDialogIndex.FromString,
                    response_serializer=messaging__pb2.ResponseFetchDialogIndex.SerializeToString,
            ),
            'DialogListDifference': grpc.unary_unary_rpc_method_handler(
                    servicer.DialogListDifference,
                    request_deserializer=messaging__pb2.RequestDialogListDifference.FromString,
                    response_serializer=messaging__pb2.ResponseDialogListDifference.SerializeToString,
            ),
            'GetLastConversationMessages': grpc.unary_unary_rpc_method_handler(
                    servicer.GetLastConversationMessages,
                    request_deserializer=messaging__pb2.RequestGetLastConversationMessages.FromString,
                    response_serializer=messaging__pb2.ResponseGetLastConversationMessages.SerializeToString,
            ),
            'LoadArchived': grpc.unary_unary_rpc_method_handler(
                    servicer.LoadArchived,
                    request_deserializer=messaging__pb2.RequestLoadArchived.FromString,
                    response_serializer=messaging__pb2.ResponseLoadArchived.SerializeToString,
            ),
            'LoadGroupedDialogs': grpc.unary_unary_rpc_method_handler(
                    servicer.LoadGroupedDialogs,
                    request_deserializer=messaging__pb2.RequestLoadGroupedDialogs.FromString,
                    response_serializer=messaging__pb2.ResponseLoadGroupedDialogs.SerializeToString,
            ),
            'HideDialog': grpc.unary_unary_rpc_method_handler(
                    servicer.HideDialog,
                    request_deserializer=messaging__pb2.RequestHideDialog.FromString,
                    response_serializer=messaging__pb2.ResponseDialogsOrder.SerializeToString,
            ),
            'ShowDialog': grpc.unary_unary_rpc_method_handler(
                    servicer.ShowDialog,
                    request_deserializer=messaging__pb2.RequestShowDialog.FromString,
                    response_serializer=messaging__pb2.ResponseDialogsOrder.SerializeToString,
            ),
            'FavouriteDialog': grpc.unary_unary_rpc_method_handler(
                    servicer.FavouriteDialog,
                    request_deserializer=messaging__pb2.RequestFavouriteDialog.FromString,
                    response_serializer=messaging__pb2.ResponseDialogsOrder.SerializeToString,
            ),
            'UnfavouriteDialog': grpc.unary_unary_rpc_method_handler(
                    servicer.UnfavouriteDialog,
                    request_deserializer=messaging__pb2.RequestUnfavouriteDialog.FromString,
                    response_serializer=messaging__pb2.ResponseDialogsOrder.SerializeToString,
            ),
            'NotifyDialogOpened': grpc.unary_unary_rpc_method_handler(
                    servicer.NotifyDialogOpened,
                    request_deserializer=messaging__pb2.RequestNotifyDialogOpened.FromString,
                    response_serializer=miscellaneous__pb2.ResponseVoid.SerializeToString,
            ),
            'PinMessage': grpc.unary_unary_rpc_method_handler(
                    servicer.PinMessage,
                    request_deserializer=messaging__pb2.RequestPinMessage.FromString,
                    response_serializer=miscellaneous__pb2.ResponseSeqDate.SerializeToString,
            ),
            'UnpinMessage': grpc.unary_unary_rpc_method_handler(
                    servicer.UnpinMessage,
                    request_deserializer=messaging__pb2.RequestUnpinMessage.FromString,
                    response_serializer=miscellaneous__pb2.ResponseSeqDate.SerializeToString,
            ),
            'GetUpdatedMessages': grpc.unary_unary_rpc_method_handler(
                    servicer.GetUpdatedMessages,
                    request_deserializer=messaging__pb2.RequestGetUpdatedMessages.FromString,
                    response_serializer=messaging__pb2.ResponseGetUpdatedMessages.SerializeToString,
            ),
            'GetMessageReads': grpc.unary_unary_rpc_method_handler(
                    servicer.GetMessageReads,
                    request_deserializer=messaging__pb2.RequestMessageReads.FromString,
                    response_serializer=messaging__pb2.ResponseMessageReads.SerializeToString,
            ),
            'GetMessageReceives': grpc.unary_unary_rpc_method_handler(
                    servicer.GetMessageReceives,
                    request_deserializer=messaging__pb2.RequestMessageReceives.FromString,
                    response_serializer=messaging__pb2.ResponseMessageReceives.SerializeToString,
            ),
            'ReadDialogLater': grpc.unary_unary_rpc_method_handler(
                    servicer.ReadDialogLater,
                    request_deserializer=messaging__pb2.RequestReadDialogLater.FromString,
                    response_serializer=miscellaneous__pb2.ResponseVoid.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'dialog.Messaging', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Messaging(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def DoInteractiveMediaAction(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dialog.Messaging/DoInteractiveMediaAction',
            messaging__pb2.RequestDoInteractiveMediaAction.SerializeToString,
            miscellaneous__pb2.ResponseVoid.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SendMessage(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dialog.Messaging/SendMessage',
            messaging__pb2.RequestSendMessage.SerializeToString,
            messaging__pb2.ResponseSendMessage.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateMessage(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dialog.Messaging/UpdateMessage',
            messaging__pb2.RequestUpdateMessage.SerializeToString,
            miscellaneous__pb2.ResponseSeqDate.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def MessageReceived(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dialog.Messaging/MessageReceived',
            messaging__pb2.RequestMessageReceived.SerializeToString,
            miscellaneous__pb2.ResponseVoid.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def MessageRead(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dialog.Messaging/MessageRead',
            messaging__pb2.RequestMessageRead.SerializeToString,
            miscellaneous__pb2.ResponseVoid.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteMessageObsolete(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dialog.Messaging/DeleteMessageObsolete',
            messaging__pb2.RequestDeleteMessageObsolete.SerializeToString,
            miscellaneous__pb2.ResponseSeq.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteMessage(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dialog.Messaging/DeleteMessage',
            messaging__pb2.RequestDeleteMessage.SerializeToString,
            miscellaneous__pb2.ResponseVoid.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ClearChat(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dialog.Messaging/ClearChat',
            messaging__pb2.RequestClearChat.SerializeToString,
            miscellaneous__pb2.ResponseSeq.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteChat(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dialog.Messaging/DeleteChat',
            messaging__pb2.RequestDeleteChat.SerializeToString,
            miscellaneous__pb2.ResponseSeq.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ArchiveChat(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dialog.Messaging/ArchiveChat',
            messaging__pb2.RequestArchiveChat.SerializeToString,
            miscellaneous__pb2.ResponseSeq.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def MessageSetReaction(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dialog.Messaging/MessageSetReaction',
            messaging__pb2.RequestMessageSetReaction.SerializeToString,
            messaging__pb2.ResponseReactionsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def MessageRemoveReaction(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dialog.Messaging/MessageRemoveReaction',
            messaging__pb2.RequestMessageRemoveReaction.SerializeToString,
            messaging__pb2.ResponseReactionsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def LoadHistory(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dialog.Messaging/LoadHistory',
            messaging__pb2.RequestLoadHistory.SerializeToString,
            messaging__pb2.ResponseLoadHistory.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def HistoryDifference(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dialog.Messaging/HistoryDifference',
            messaging__pb2.RequestHistoryDifference.SerializeToString,
            messaging__pb2.ResponseHistoryDifference.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def LoadDialogs(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dialog.Messaging/LoadDialogs',
            messaging__pb2.RequestLoadDialogs.SerializeToString,
            messaging__pb2.ResponseLoadDialogs.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def FetchDialogIndex(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dialog.Messaging/FetchDialogIndex',
            messaging__pb2.RequestFetchDialogIndex.SerializeToString,
            messaging__pb2.ResponseFetchDialogIndex.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DialogListDifference(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dialog.Messaging/DialogListDifference',
            messaging__pb2.RequestDialogListDifference.SerializeToString,
            messaging__pb2.ResponseDialogListDifference.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetLastConversationMessages(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dialog.Messaging/GetLastConversationMessages',
            messaging__pb2.RequestGetLastConversationMessages.SerializeToString,
            messaging__pb2.ResponseGetLastConversationMessages.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def LoadArchived(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dialog.Messaging/LoadArchived',
            messaging__pb2.RequestLoadArchived.SerializeToString,
            messaging__pb2.ResponseLoadArchived.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def LoadGroupedDialogs(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dialog.Messaging/LoadGroupedDialogs',
            messaging__pb2.RequestLoadGroupedDialogs.SerializeToString,
            messaging__pb2.ResponseLoadGroupedDialogs.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def HideDialog(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dialog.Messaging/HideDialog',
            messaging__pb2.RequestHideDialog.SerializeToString,
            messaging__pb2.ResponseDialogsOrder.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ShowDialog(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dialog.Messaging/ShowDialog',
            messaging__pb2.RequestShowDialog.SerializeToString,
            messaging__pb2.ResponseDialogsOrder.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def FavouriteDialog(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dialog.Messaging/FavouriteDialog',
            messaging__pb2.RequestFavouriteDialog.SerializeToString,
            messaging__pb2.ResponseDialogsOrder.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UnfavouriteDialog(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dialog.Messaging/UnfavouriteDialog',
            messaging__pb2.RequestUnfavouriteDialog.SerializeToString,
            messaging__pb2.ResponseDialogsOrder.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def NotifyDialogOpened(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dialog.Messaging/NotifyDialogOpened',
            messaging__pb2.RequestNotifyDialogOpened.SerializeToString,
            miscellaneous__pb2.ResponseVoid.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def PinMessage(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dialog.Messaging/PinMessage',
            messaging__pb2.RequestPinMessage.SerializeToString,
            miscellaneous__pb2.ResponseSeqDate.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UnpinMessage(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dialog.Messaging/UnpinMessage',
            messaging__pb2.RequestUnpinMessage.SerializeToString,
            miscellaneous__pb2.ResponseSeqDate.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetUpdatedMessages(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dialog.Messaging/GetUpdatedMessages',
            messaging__pb2.RequestGetUpdatedMessages.SerializeToString,
            messaging__pb2.ResponseGetUpdatedMessages.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetMessageReads(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dialog.Messaging/GetMessageReads',
            messaging__pb2.RequestMessageReads.SerializeToString,
            messaging__pb2.ResponseMessageReads.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetMessageReceives(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dialog.Messaging/GetMessageReceives',
            messaging__pb2.RequestMessageReceives.SerializeToString,
            messaging__pb2.ResponseMessageReceives.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ReadDialogLater(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dialog.Messaging/ReadDialogLater',
            messaging__pb2.RequestReadDialogLater.SerializeToString,
            miscellaneous__pb2.ResponseVoid.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



import os
import setuptools


def readme():
    with open('README.md') as f:
        return f.read()


def version():
    return os.getenv('CIRCLE_TAG')


setuptools.setup(
    name="dialog-api",
    version=version(),
    author="Dialog LLC",
    author_email="services@dlg.im",
    description="Dialog API for Python",
    long_description=readme(),
    long_description_content_type="text/markdown",
    url="https://github.com/dialogs/api-schema",
    packages=setuptools.find_packages(),
    license='Apache License 2.0',
    keywords='dialog messenger',
    python_requires='>=3',
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: Apache Software License",
        "Operating System :: OS Independent",
    ],
)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from . import device_info_pb2 as device__info__pb2
from . import miscellaneous_pb2 as miscellaneous__pb2


class DeviceInfoStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.NotifyAboutDeviceInfo = channel.unary_unary(
                '/dialog.DeviceInfo/NotifyAboutDeviceInfo',
                request_serializer=device__info__pb2.RequestNotifyAboutDeviceInfo.SerializeToString,
                response_deserializer=miscellaneous__pb2.ResponseVoid.FromString,
                )


class DeviceInfoServicer(object):
    """Missing associated documentation comment in .proto file."""

    def NotifyAboutDeviceInfo(self, request, context):
        """/ Set info about current device
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_DeviceInfoServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'NotifyAboutDeviceInfo': grpc.unary_unary_rpc_method_handler(
                    servicer.NotifyAboutDeviceInfo,
                    request_deserializer=device__info__pb2.RequestNotifyAboutDeviceInfo.FromString,
                    response_serializer=miscellaneous__pb2.ResponseVoid.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'dialog.DeviceInfo', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class DeviceInfo(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def NotifyAboutDeviceInfo(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dialog.DeviceInfo/NotifyAboutDeviceInfo',
            device__info__pb2.RequestNotifyAboutDeviceInfo.SerializeToString,
            miscellaneous__pb2.ResponseVoid.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from . import miscellaneous_pb2 as miscellaneous__pb2
from . import privacy_pb2 as privacy__pb2


class PrivacyStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.BlockUser = channel.unary_unary(
                '/dialog.Privacy/BlockUser',
                request_serializer=privacy__pb2.RequestBlockUser.SerializeToString,
                response_deserializer=miscellaneous__pb2.ResponseSeq.FromString,
                )
        self.UnblockUser = channel.unary_unary(
                '/dialog.Privacy/UnblockUser',
                request_serializer=privacy__pb2.RequestUnblockUser.SerializeToString,
                response_deserializer=miscellaneous__pb2.ResponseSeq.FromString,
                )
        self.LoadBlockedUsers = channel.unary_unary(
                '/dialog.Privacy/LoadBlockedUsers',
                request_serializer=privacy__pb2.RequestLoadBlockedUsers.SerializeToString,
                response_deserializer=privacy__pb2.ResponseLoadBlockedUsers.FromString,
                )


class PrivacyServicer(object):
    """Missing associated documentation comment in .proto file."""

    def BlockUser(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UnblockUser(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def LoadBlockedUsers(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_PrivacyServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'BlockUser': grpc.unary_unary_rpc_method_handler(
                    servicer.BlockUser,
                    request_deserializer=privacy__pb2.RequestBlockUser.FromString,
                    response_serializer=miscellaneous__pb2.ResponseSeq.SerializeToString,
            ),
            'UnblockUser': grpc.unary_unary_rpc_method_handler(
                    servicer.UnblockUser,
                    request_deserializer=privacy__pb2.RequestUnblockUser.FromString,
                    response_serializer=miscellaneous__pb2.ResponseSeq.SerializeToString,
            ),
            'LoadBlockedUsers': grpc.unary_unary_rpc_method_handler(
                    servicer.LoadBlockedUsers,
                    request_deserializer=privacy__pb2.RequestLoadBlockedUsers.FromString,
                    response_serializer=privacy__pb2.ResponseLoadBlockedUsers.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'dialog.Privacy', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Privacy(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def BlockUser(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dialog.Privacy/BlockUser',
            privacy__pb2.RequestBlockUser.SerializeToString,
            miscellaneous__pb2.ResponseSeq.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UnblockUser(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dialog.Privacy/UnblockUser',
            privacy__pb2.RequestUnblockUser.SerializeToString,
            miscellaneous__pb2.ResponseSeq.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def LoadBlockedUsers(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dialog.Privacy/LoadBlockedUsers',
            privacy__pb2.RequestLoadBlockedUsers.SerializeToString,
            privacy__pb2.ResponseLoadBlockedUsers.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from . import obsolete_pb2 as obsolete__pb2


class ObsoleteStub(object):
    """/ deprecated
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Obsolete = channel.unary_unary(
                '/dialog.Obsolete/Obsolete',
                request_serializer=google_dot_protobuf_dot_wrappers__pb2.BytesValue.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_wrappers__pb2.BytesValue.FromString,
                )
        self.SeqUpdates = channel.unary_stream(
                '/dialog.Obsolete/SeqUpdates',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=obsolete__pb2.ObsoleteSeqUpdateBox.FromString,
                )
        self.WeakUpdates = channel.stream_stream(
                '/dialog.Obsolete/WeakUpdates',
                request_serializer=obsolete__pb2.ObsoleteWeakUpdateCommand.SerializeToString,
                response_deserializer=obsolete__pb2.ObsoleteWeakUpdateBox.FromString,
                )


class ObsoleteServicer(object):
    """/ deprecated
    """

    def Obsolete(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SeqUpdates(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def WeakUpdates(self, request_iterator, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ObsoleteServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Obsolete': grpc.unary_unary_rpc_method_handler(
                    servicer.Obsolete,
                    request_deserializer=google_dot_protobuf_dot_wrappers__pb2.BytesValue.FromString,
                    response_serializer=google_dot_protobuf_dot_wrappers__pb2.BytesValue.SerializeToString,
            ),
            'SeqUpdates': grpc.unary_stream_rpc_method_handler(
                    servicer.SeqUpdates,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=obsolete__pb2.ObsoleteSeqUpdateBox.SerializeToString,
            ),
            'WeakUpdates': grpc.stream_stream_rpc_method_handler(
                    servicer.WeakUpdates,
                    request_deserializer=obsolete__pb2.ObsoleteWeakUpdateCommand.FromString,
                    response_serializer=obsolete__pb2.ObsoleteWeakUpdateBox.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'dialog.Obsolete', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Obsolete(object):
    """/ deprecated
    """

    @staticmethod
    def Obsolete(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dialog.Obsolete/Obsolete',
            google_dot_protobuf_dot_wrappers__pb2.BytesValue.SerializeToString,
            google_dot_protobuf_dot_wrappers__pb2.BytesValue.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SeqUpdates(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/dialog.Obsolete/SeqUpdates',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            obsolete__pb2.ObsoleteSeqUpdateBox.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def WeakUpdates(request_iterator,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.stream_stream(request_iterator, target, '/dialog.Obsolete/WeakUpdates',
            obsolete__pb2.ObsoleteWeakUpdateCommand.SerializeToString,
            obsolete__pb2.ObsoleteWeakUpdateBox.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from . import registration_pb2 as registration__pb2


class RegistrationStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ExchangeAuthIdForToken = channel.unary_unary(
                '/dialog.Registration/ExchangeAuthIdForToken',
                request_serializer=registration__pb2.RequestExchangeAuthIdForToken.SerializeToString,
                response_deserializer=registration__pb2.ResponseDeviceRequest.FromString,
                )
        self.RegisterDevice = channel.unary_unary(
                '/dialog.Registration/RegisterDevice',
                request_serializer=registration__pb2.RequestRegisterDevice.SerializeToString,
                response_deserializer=registration__pb2.ResponseDeviceRequest.FromString,
                )
        self.RegisterDeprecatedDevice = channel.unary_unary(
                '/dialog.Registration/RegisterDeprecatedDevice',
                request_serializer=registration__pb2.RegisterDeprecatedDeviceRequest.SerializeToString,
                response_deserializer=registration__pb2.ResponseDeviceRequest.FromString,
                )


class RegistrationServicer(object):
    """Missing associated documentation comment in .proto file."""

    def ExchangeAuthIdForToken(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RegisterDevice(self, request, context):
        """/ register device to get auth token
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RegisterDeprecatedDevice(self, request, context):
        """deprecated
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_RegistrationServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ExchangeAuthIdForToken': grpc.unary_unary_rpc_method_handler(
                    servicer.ExchangeAuthIdForToken,
                    request_deserializer=registration__pb2.RequestExchangeAuthIdForToken.FromString,
                    response_serializer=registration__pb2.ResponseDeviceRequest.SerializeToString,
            ),
            'RegisterDevice': grpc.unary_unary_rpc_method_handler(
                    servicer.RegisterDevice,
                    request_deserializer=registration__pb2.RequestRegisterDevice.FromString,
                    response_serializer=registration__pb2.ResponseDeviceRequest.SerializeToString,
            ),
            'RegisterDeprecatedDevice': grpc.unary_unary_rpc_method_handler(
                    servicer.RegisterDeprecatedDevice,
                    request_deserializer=registration__pb2.RegisterDeprecatedDeviceRequest.FromString,
                    response_serializer=registration__pb2.ResponseDeviceRequest.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'dialog.Registration', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Registration(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def ExchangeAuthIdForToken(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dialog.Registration/ExchangeAuthIdForToken',
            registration__pb2.RequestExchangeAuthIdForToken.SerializeToString,
            registration__pb2.ResponseDeviceRequest.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RegisterDevice(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dialog.Registration/RegisterDevice',
            registration__pb2.RequestRegisterDevice.SerializeToString,
            registration__pb2.ResponseDeviceRequest.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RegisterDeprecatedDevice(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dialog.Registration/RegisterDeprecatedDevice',
            registration__pb2.RegisterDeprecatedDeviceRequest.SerializeToString,
            registration__pb2.ResponseDeviceRequest.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from . import miscellaneous_pb2 as miscellaneous__pb2
from . import threads_pb2 as threads__pb2


class ThreadsStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.CreateThread = channel.unary_unary(
                '/dialog.Threads/CreateThread',
                request_serializer=threads__pb2.RequestCreateThread.SerializeToString,
                response_deserializer=threads__pb2.ResponseCreateThread.FromString,
                )
        self.LiftThread = channel.unary_unary(
                '/dialog.Threads/LiftThread',
                request_serializer=threads__pb2.RequestLiftThread.SerializeToString,
                response_deserializer=threads__pb2.ResponseLiftThread.FromString,
                )
        self.LoadGroupThreads = channel.unary_unary(
                '/dialog.Threads/LoadGroupThreads',
                request_serializer=threads__pb2.RequestLoadGroupThreads.SerializeToString,
                response_deserializer=threads__pb2.ResponseLoadGroupThreads.FromString,
                )
        self.JoinThread = channel.unary_unary(
                '/dialog.Threads/JoinThread',
                request_serializer=threads__pb2.RequestJoinThread.SerializeToString,
                response_deserializer=miscellaneous__pb2.ResponseVoid.FromString,
                )


class ThreadsServicer(object):
    """Missing associated documentation comment in .proto file."""

    def CreateThread(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def LiftThread(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def LoadGroupThreads(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def JoinThread(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ThreadsServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'CreateThread': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateThread,
                    request_deserializer=threads__pb2.RequestCreateThread.FromString,
                    response_serializer=threads__pb2.ResponseCreateThread.SerializeToString,
            ),
            'LiftThread': grpc.unary_unary_rpc_method_handler(
                    servicer.LiftThread,
                    request_deserializer=threads__pb2.RequestLiftThread.FromString,
                    response_serializer=threads__pb2.ResponseLiftThread.SerializeToString,
            ),
            'LoadGroupThreads': grpc.unary_unary_rpc_method_handler(
                    servicer.LoadGroupThreads,
                    request_deserializer=threads__pb2.RequestLoadGroupThreads.FromString,
                    response_serializer=threads__pb2.ResponseLoadGroupThreads.SerializeToString,
            ),
            'JoinThread': grpc.unary_unary_rpc_method_handler(
                    servicer.JoinThread,
                    request_deserializer=threads__pb2.RequestJoinThread.FromString,
                    response_serializer=miscellaneous__pb2.ResponseVoid.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'dialog.Threads', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Threads(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def CreateThread(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dialog.Threads/CreateThread',
            threads__pb2.RequestCreateThread.SerializeToString,
            threads__pb2.ResponseCreateThread.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def LiftThread(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dialog.Threads/LiftThread',
            threads__pb2.RequestLiftThread.SerializeToString,
            threads__pb2.ResponseLiftThread.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def LoadGroupThreads(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dialog.Threads/LoadGroupThreads',
            threads__pb2.RequestLoadGroupThreads.SerializeToString,
            threads__pb2.ResponseLoadGroupThreads.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def JoinThread(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dialog.Threads/JoinThread',
            threads__pb2.RequestJoinThread.SerializeToString,
            miscellaneous__pb2.ResponseVoid.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
